@@ -55,7 +55,7 @@ def transform_nx_gt(g,rescale=False):
         h.vp.lat = h.new_vertex_property("double")
         h.vp.long = h.new_vertex_property("double")
         h.ep.weight = h.new_edge_property("float")
-    h.ep.air = h.new_edge_property("bool")
+    h.ep.type = h.new_edge_property("int32_t")
     h.gp.rescaled = h.new_graph_property("bool")
     h.gp.rescaled = rescale
     pos2vertex = {}
@@ -72,10 +72,10 @@ def transform_nx_gt(g,rescale=False):
         h.vp.long[v] = int(n[2]*10000000) if rescale else n[2]
     for n,m,d in g.edges.data(data=True):
         w = d['weight']
-        air = d['air']
+        air = d['type']
         e = h.add_edge(pos2vertex[n[1],n[2]],pos2vertex[m[1],m[2]])
-        h.ep.air[e] = air
-        if rescale and air:
+        h.ep.type[e] = air
+        if rescale and air < 0:
             w = haversine_distance(longx=n[2],latx=n[1],longy=m[2],laty=m[1])
         h.ep.weight[e] = int(w*1000) if rescale else w
     return h
@@ -97,7 +97,7 @@ def convert_nx_gt(file_name_in,file_name_out,rescale=False):
     file_size(file_name_out)
 
 def transform_nx_npz(g,rescale=False):
-    from numpy import array, int64, int32, float64, float32
+    from numpy import array, int64, int32, int16, float64, float32
     from limic.util import haversine_distance
     vs = g.nodes()
     es = g.edges.data(data=True)
@@ -120,8 +120,8 @@ def transform_nx_npz(g,rescale=False):
         ns.append([])
     for e in es:
         w = e[2]['weight']
-        air = e[2]['air']
-        if rescale and air:
+        air = e[2]['type']
+        if rescale and air < 0:
             w = int(1000*haversine_distance(longx=e[0][2],latx=e[0][1],longy=e[1][2],laty=e[1][1]))
         f = v2index[e[0]]
         t = v2index[e[1]]
@@ -146,7 +146,7 @@ def transform_nx_npz(g,rescale=False):
         h['long'] = array(long,dtype=float64)
         h['edges_weight'] = array(edges_weight,dtype=float32)
     h['id2edges'] = array(id2edges,dtype=int32)
-    h['edges_air'] = array(edges_air,dtype=bool)
+    h['edges_type'] = array(edges_air,dtype=int16)
     h['edges_neighbor'] = array(edges_neighbor,dtype=int32)
     return h
 
@@ -194,10 +194,10 @@ def convert_gt_nx(file_name_in,file_name_out,penalize=20):
     file_size(file_name_out)            
 
 def transform_gt_npz(g,penalize=20):
-    from numpy import array, int64, int32, float64, float32
+    from numpy import array, int64, int32, int16, float64, float32
     vs = g.get_vertices([g.vp.id,g.vp.lat,g.vp.long])
     rescale = g.gp.rescaled
-    es = g.get_edges([g.ep.weight,g.ep.air])
+    es = g.get_edges([g.ep.weight,g.ep.type])
     ids = [None]*len(vs)
     lat = [None]*len(vs)
     long = [None]*len(vs)
@@ -234,7 +234,7 @@ def transform_gt_npz(g,penalize=20):
     h['id2edges'] = array(id2edges,dtype=int32)
     h['edges_weight'] = array(edges_weight,dtype=float32)
     h['edges_neighbor'] = array(edges_neighbor,dtype=int32)
-    h['edges_air'] = array(edges_air,dtype=bool)
+    h['edges_type'] = array(edges_air,dtype=int16)
     return h
 
 def convert_gt_npz(file_name_in,file_name_out,penalize=20):
@@ -261,7 +261,7 @@ def transform_npz_nx(g,penalize=20):
     id2edges = g['id2edges']
     edges_weight = g['edges_weight']
     edges_neighbor = g['edges_neighbor']
-    edges_air = g['edges_air']
+    edges_air = g['edges_type']
     rescale = edges_weight.dtype == int32
     from networkx import Graph
     h = Graph()
@@ -276,9 +276,9 @@ def transform_npz_nx(g,penalize=20):
         me = index2node[index]
         for i in range(left,right):
             neighbor = edges_neighbor[i]
-            air = bool(edges_air[i])
-            w = edges_weight[i]/((1000.*(penalize if air else 1)) if rescale else 1)
-            h.add_edge(me,index2node[neighbor],weight=w,air=air)
+            air = edges_air[i]
+            w = edges_weight[i]/((1000.*(penalize if air < 0 else 1)) if rescale else 1)
+            h.add_edge(me,index2node[neighbor],weight=w,type=air)
     return h
 
 def convert_npz_nx(file_name_in,file_name_out,penalize=20):
