@@ -271,3 +271,16 @@ def save_path(costpath,out_file=None,visualize=False):
     else:
         file = open(out_file,"w") if out_file else stdout
         print("node(id:"+",".join(map(lambda x:str(x[3]),path))+");out;",file=file)
+def split(file,sep=None,maxsplit=-1,chunk=2**16):
+    rest = ""
+    while True:
+        data = file.read(chunk)
+        if not data:
+            break
+        if rest:
+            data = rest+data            
+        parts = data.split(sep=sep,maxsplit=maxsplit)
+        rest = parts.pop()
+        for part in parts:
+            yield part
+    yield rest
